==> vertx-stack-docs-3.4.0-html.zip: ceylondoc/vertx-auth-jdbc/.resources/index.js <==
var index = [
{'name': 'io.vertx.ceylon.auth.jdbc', 'type': 'package', 'url': 'index.html#section-package', 'doc': '', 'tags': [],'icons': ['icon-package']},
{'name': 'JDBCAuthOptions.toJson', 'type': 'function', 'url': 'JDBCAuthOptions.type.html#toJson', 'doc': '', 'tags': [],'icons': ['icon-shared-member', 'icon-decoration-impl']},
{'name': 'JDBCAuthOptions', 'type': 'class', 'url': 'JDBCAuthOptions.type.html', 'doc': '<p>Options configuring JDBC authentication.</p>', 'tags': [],'icons': ['icon-class']},
{'name': 'jdbcAuthOptions.fromJson', 'type': 'function', 'url': 'jdbcAuthOptions.object.html#fromJson', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'toJava.convert', 'type': 'function', 'url': 'jdbcAuthOptions.toJava.object.html#convert', 'doc': '', 'tags': [],'icons': ['icon-shared-member', 'icon-decoration-impl']},
{'name': 'toJava', 'type': 'object', 'url': 'jdbcAuthOptions.toJava.object.html', 'doc': '', 'tags': [],'icons': ['icon-object']},
{'name': 'jdbcAuthOptions.toJava', 'type': 'value', 'url': 'jdbcAuthOptions.object.html#toJava', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'jdbcAuthOptions.toJson', 'type': 'function', 'url': 'jdbcAuthOptions.object.html#toJson', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'jdbcAuthOptions', 'type': 'object', 'url': 'jdbcAuthOptions.object.html', 'doc': '', 'tags': [],'icons': ['icon-object']},
{'name': 'jdbcAuthOptions', 'type': 'value', 'url': 'index.html#jdbcAuthOptions', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'jdbcAuth.create', 'type': 'function', 'url': 'jdbcAuth.object.html#create', 'doc': '<p>Create a JDBC auth provider implementation</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'jdbcAuth', 'type': 'object', 'url': 'jdbcAuth.object.html', 'doc': '', 'tags': [],'icons': ['icon-object']},
{'name': 'jdbcAuth', 'type': 'value', 'url': 'index.html#jdbcAuth', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'JDBCAuth.setAuthenticationQuery', 'type': 'function', 'url': 'JDBCAuth.type.html#setAuthenticationQuery', 'doc': '<p>Set the authentication query to use.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'JDBCAuth.setRolesQuery', 'type': 'function', 'url': 'JDBCAuth.type.html#setRolesQuery', 'doc': '<p>Set the roles query to use.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'JDBCAuth.setPermissionsQuery', 'type': 'function', 'url': 'JDBCAuth.type.html#setPermissionsQuery', 'doc': '<p>Set the permissions query to use.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'JDBCAuth.setRolePrefix', 'type': 'function', 'url': 'JDBCAuth.type.html#setRolePrefix', 'doc': '<p>Set the role prefix to distinguish from permissions when checking for isPermitted requests.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'JDBCAuth.generateSalt', 'type': 'function', 'url': 'JDBCAuth.type.html#generateSalt', 'doc': '<p>Compute a salt string.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'JDBCAuth.computeHash', 'type': 'function', 'url': 'JDBCAuth.type.html#computeHash', 'doc': '<p>Compute the hashed password given the unhashed password and the salt</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'JDBCAuth', 'type': 'class', 'url': 'JDBCAuth.type.html', 'doc': '<p>Factory interface for creating <code>io.vertx.ext.auth.AuthProvider</code> instances that use the Vert.x JDBC client</p>', 'tags': [],'icons': ['icon-class']},
{'name': 'io.vertx.ceylon.auth.jdbc', 'type': 'module', 'url': 'index.html', 'doc': '', 'tags': [],'icons': ['icon-module']}];
var tagIndex = [
];

==> vertx-stack-docs-3.4.2-html.zip: ceylondoc/vertx-auth-jdbc/.resources/index.js <==
var index = [
{'name': 'io.vertx.ceylon.auth.jdbc', 'type': 'package', 'url': 'index.html#section-package', 'doc': '', 'tags': [],'icons': ['icon-package']},
{'name': 'JDBCAuthOptions.toJson', 'type': 'function', 'url': 'JDBCAuthOptions.type.html#toJson', 'doc': '', 'tags': [],'icons': ['icon-shared-member', 'icon-decoration-impl']},
{'name': 'JDBCAuthOptions', 'type': 'class', 'url': 'JDBCAuthOptions.type.html', 'doc': '<p>Options configuring JDBC authentication.</p>', 'tags': [],'icons': ['icon-class']},
{'name': 'jdbcAuthOptions.fromJson', 'type': 'function', 'url': 'jdbcAuthOptions.object.html#fromJson', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'toJava.convert', 'type': 'function', 'url': 'jdbcAuthOptions.toJava.object.html#convert', 'doc': '', 'tags': [],'icons': ['icon-shared-member', 'icon-decoration-impl']},
{'name': 'toJava', 'type': 'object', 'url': 'jdbcAuthOptions.toJava.object.html', 'doc': '', 'tags': [],'icons': ['icon-object']},
{'name': 'jdbcAuthOptions.toJava', 'type': 'value', 'url': 'jdbcAuthOptions.object.html#toJava', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'jdbcAuthOptions.toJson', 'type': 'function', 'url': 'jdbcAuthOptions.object.html#toJson', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'jdbcAuthOptions', 'type': 'object', 'url': 'jdbcAuthOptions.object.html', 'doc': '', 'tags': [],'icons': ['icon-object']},
{'name': 'jdbcAuthOptions', 'type': 'value', 'url': 'index.html#jdbcAuthOptions', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'jdbcAuth.create', 'type': 'function', 'url': 'jdbcAuth.object.html#create', 'doc': '<p>Create a JDBC auth provider implementation</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'jdbcAuth', 'type': 'object', 'url': 'jdbcAuth.object.html', 'doc': '', 'tags': [],'icons': ['icon-object']},
{'name': 'jdbcAuth', 'type': 'value', 'url': 'index.html#jdbcAuth', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'JDBCAuth.setAuthenticationQuery', 'type': 'function', 'url': 'JDBCAuth.type.html#setAuthenticationQuery', 'doc': '<p>Set the authentication query to use.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'JDBCAuth.setRolesQuery', 'type': 'function', 'url': 'JDBCAuth.type.html#setRolesQuery', 'doc': '<p>Set the roles query to use.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'JDBCAuth.setPermissionsQuery', 'type': 'function', 'url': 'JDBCAuth.type.html#setPermissionsQuery', 'doc': '<p>Set the permissions query to use.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'JDBCAuth.setRolePrefix', 'type': 'function', 'url': 'JDBCAuth.type.html#setRolePrefix', 'doc': '<p>Set the role prefix to distinguish from permissions when checking for isPermitted requests.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'JDBCAuth.computeHash', 'type': 'function', 'url': 'JDBCAuth.type.html#computeHash', 'doc': '<p>Compute the hashed password given the unhashed password and the salt</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'JDBCAuth.computeHash', 'type': 'function', 'url': 'JDBCAuth.type.html#computeHash', 'doc': '<p>Compute the hashed password given the unhashed password and the salt without nonce</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'JDBCAuth.computeHash', 'type': 'function', 'url': 'JDBCAuth.type.html#computeHash', 'doc': '<p>Compute the hashed password given the unhashed password and the salt</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'JDBCAuth.generateSalt', 'type': 'function', 'url': 'JDBCAuth.type.html#generateSalt', 'doc': '<p>Compute a salt string.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'JDBCAuth.setNonces', 'type': 'function', 'url': 'JDBCAuth.type.html#setNonces', 'doc': '<p>Provide a application configuration level on hash nonce\'s as a ordered list of\nnonces where each position corresponds…</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'JDBCAuth', 'type': 'class', 'url': 'JDBCAuth.type.html', 'doc': '<p>Factory interface for creating <code>io.vertx.ext.auth.AuthProvider</code> instances that use the Vert.x JDBC client</p>', 'tags': [],'icons': ['icon-class']},
{'name': 'io.vertx.ceylon.auth.jdbc', 'type': 'module', 'url': 'index.html', 'doc': '', 'tags': [],'icons': ['icon-module']}];
var tagIndex = [
];
